pub struct SocketAddr {
pub(super) len: u32,
}🔬This is a nightly-only experimental API. (
windows_unix_domain_sockets #150487)Available on Windows only.
Fields
len: u32🔬This is a nightly-only experimental API. (
windows_unix_domain_sockets #150487)Implementations
Sourceimpl SocketAddr
impl SocketAddr
Sourcepub fn as_pathname(&self) -> Option<&Path>
🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)
pub fn as_pathname(&self) -> Option<&Path>
windows_unix_domain_sockets #150487)Returns the contents of this address if it is a pathname address.
Examples
With a pathname:
#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::UnixListener;
use std::path::Path;
fn main() -> std::io::Result<()> {
let socket = UnixListener::bind("/tmp/sock")?;
let addr = socket.local_addr().expect("Couldn't get local address");
assert_eq!(addr.as_pathname(), Some(Path::new("/tmp/sock")));
Ok(())
}Sourcepub fn from_pathname<P>(path: P) -> Result<SocketAddr>
🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)
pub fn from_pathname<P>(path: P) -> Result<SocketAddr>
windows_unix_domain_sockets #150487)Constructs a SockAddr with the family AF_UNIX and the provided path.
Errors
Returns an error if the path is longer than SUN_LEN or if it contains
NULL bytes.
Examples
#![feature(windows_unix_domain_sockets)]
use std::os::windows::net::SocketAddr;
use std::path::Path;
let address = SocketAddr::from_pathname("/path/to/socket")?;
assert_eq!(address.as_pathname(), Some(Path::new("/path/to/socket")));Creating a SocketAddr with a NULL byte results in an error.
fn address(&self) -> AddressKind<'_>
🔬This is a nightly-only experimental API. (
windows_unix_domain_sockets #150487)Sourcepub fn is_unnamed(&self) -> bool
🔬This is a nightly-only experimental API. (windows_unix_domain_sockets #150487)
pub fn is_unnamed(&self) -> bool
windows_unix_domain_sockets #150487)Trait Implementations